@@ -1,13 +1,15 @@
 /*
- * Logswan 2.1.10
+ * Logswan 2.1.11
  * Copyright (c) 2015-2021, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2021-02-15
+ * Last Updated: 2021-11-16
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
+ *
+ * SPDX-License-Identifier: BSD-2-Clause
  */
 
 #include <sys/socket.h>
@@ -73,7 +75,8 @@ main(int argc, char *argv[])
 	int opt;
 
 	const char *errstr;
-	char linebuffer[LINE_LENGTH_MAX];
+	char *linebuffer = NULL;
+	size_t linesize = 0;
 	char *input;
 	char *db = NULL;
 
@@ -101,9 +104,6 @@ main(int argc, char *argv[])
 	}
 #endif
 
-	hll_init(&unique_ipv4, HLL_BITS);
-	hll_init(&unique_ipv6, HLL_BITS);
-
 	while ((opt = getopt(argc, argv, "d:ghv")) != -1) {
 		switch (opt) {
 		case 'd':
@@ -131,6 +131,9 @@ main(int argc, char *argv[])
 		return EXIT_SUCCESS;
 	}
 
+	hll_init(&unique_ipv4, HLL_BITS);
+	hll_init(&unique_ipv6, HLL_BITS);
+
 	/* Starting timer */
 	clock_gettime(CLOCK_MONOTONIC, &begin);
 
@@ -165,7 +168,7 @@ main(int argc, char *argv[])
 	results.file_name = input;
 	results.file_size = logfile_stat.st_size;
 
-	while (fgets(linebuffer, LINE_LENGTH_MAX, logfile)) {
+	while (getline(&linebuffer, &linesize, logfile) != -1) {
 		/* Parse and tokenize line */
 		parse_line(&parsed_line, linebuffer);
 
@@ -313,6 +316,7 @@ main(int argc, char *argv[])
 	fprintf(stderr, "Processed %" PRIu64 " lines in %f seconds.\n", results.processed_lines, results.runtime);
 
 	/* Clean up */
+	free(linebuffer);
 	fclose(logfile);
 
 	if (geoip)
